Welcome to singlecell-cookbook's documentation!
===============================================

A collection of tools for analyzing single-cell genomics data.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   api
   development

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
